@@ -17,6 +17,8 @@
 // This program checks that the implementation of the COO data
 // interface only uses StarPU's public API
 
+#define starpu_interface_coo_ops my_starpu_interface_coo_ops
+#define starpu_coo_data_register my_starpu_coo_data_register
 #include "../../src/datawizard/interfaces/coo_interface.c"
 
 int main()
