@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2017  Université de Bordeaux
- * Copyright (C) 2010, 2011, 2012, 2013, 2015, 2016  CNRS
+ * Copyright (C) 2009-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -27,12 +26,17 @@
 #include "xlu.h"
 #include "xlu_kernels.h"
 
+#ifdef STARPU_HAVE_VALGRIND_H
+#include <valgrind/valgrind.h>
+#endif
+
 static unsigned long size = 0;
 static unsigned nblocks = 0;
 static unsigned check = 0;
 static unsigned pivot = 0;
 static unsigned no_stride = 0;
 static unsigned profile = 0;
+static unsigned no_prio=0;
 unsigned bound = 0;
 unsigned bounddeps = 0;
 unsigned boundprio = 0;
@@ -109,6 +113,10 @@ static void parse_args(int argc, char **argv)
 
 static void display_matrix(TYPE *m, unsigned n, unsigned ld, char *str)
 {
+	(void)m;
+	(void)n;
+	(void)ld;
+	(void)str;
 #if 0
 	FPRINTF(stderr, "***********\n");
 	FPRINTF(stderr, "Display matrix %s\n", str);
@@ -170,7 +178,11 @@ void copy_matrix_into_blocks(void)
 static void init_matrix(void)
 {
 	/* allocate matrix */
+#ifdef STARPU_SIMGRID
+	A = (void*) 1;
+#else
 	starpu_malloc_flags((void **)&A, (size_t)size*size*sizeof(TYPE), STARPU_MALLOC_PINNED|STARPU_MALLOC_SIMULATION_FOLDED);
+#endif
 	STARPU_ASSERT(A);
 
 	starpu_srand48((long int)time(NULL));
@@ -338,6 +350,11 @@ int main(int argc, char **argv)
 
 	parse_args(argc, argv);
 
+#ifdef STARPU_HAVE_VALGRIND_H
+	if (RUNNING_ON_VALGRIND)
+		size = 16;
+#endif
+
 	starpu_cublas_init();
 
 	init_matrix();
@@ -362,7 +379,7 @@ int main(int argc, char **argv)
 			A_blocks = malloc(nblocks*nblocks*sizeof(TYPE *));
 			copy_matrix_into_blocks();
 
-			ret = STARPU_LU(lu_decomposition_pivot_no_stride)(A_blocks, ipiv, size, size, nblocks);
+			ret = STARPU_LU(lu_decomposition_pivot_no_stride)(A_blocks, ipiv, size, size, nblocks, no_prio);
 
 			copy_blocks_into_matrix();
 			free(A_blocks);
@@ -374,7 +391,7 @@ int main(int argc, char **argv)
 
 			start = starpu_timing_now();
 
-			ret = STARPU_LU(lu_decomposition_pivot)(A, ipiv, size, size, nblocks);
+			ret = STARPU_LU(lu_decomposition_pivot)(A, ipiv, size, size, nblocks, no_prio);
 
 			end = starpu_timing_now();
 
@@ -389,7 +406,7 @@ int main(int argc, char **argv)
 	else
 #endif
 	{
-		ret = STARPU_LU(lu_decomposition)(A, size, size, nblocks);
+		ret = STARPU_LU(lu_decomposition)(A, size, size, nblocks, no_prio);
 	}
 
 	if (profile)
@@ -429,12 +446,14 @@ int main(int argc, char **argv)
 
 		check_result();
 	}
-#endif
 
 	if (pivot)
 		free(ipiv);
+#endif
 
+#ifndef STARPU_SIMGRID
 	starpu_free_flags(A, (size_t)size*size*sizeof(TYPE), STARPU_MALLOC_PINNED|STARPU_MALLOC_SIMULATION_FOLDED);
+#endif
 
 	starpu_cublas_shutdown();
 
