@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2014                                     Inria
- * Copyright (C) 2010-2016                                CNRS
- * Copyright (C) 2010-2014                                Université de Bordeaux
+ * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +34,7 @@ int parallel_code(int sched_ctx)
 	starpu_sched_ctx_get_available_cpuids(sched_ctx, &cpuids, &ncpuids);
 
 //	printf("execute task of %d threads \n", ncpuids);
-#pragma omp parallel num_threads(ncpuids)
+#pragma omp parallel num_threads(ncpuids) reduction(+:t)
 	{
 		starpu_sched_ctx_bind_current_thread_to_cpuid(cpuids[omp_get_thread_num()]);
 // 			printf("cpu = %d ctx%d nth = %d\n", sched_getcpu(), sched_ctx, omp_get_num_threads());
@@ -49,8 +47,9 @@ int parallel_code(int sched_ctx)
 	return t;
 }
 
-static void sched_ctx_func(void *descr[] STARPU_ATTRIBUTE_UNUSED, void *arg)
+static void sched_ctx_func(void *descr[], void *arg)
 {
+	(void)descr;
 	unsigned sched_ctx = (uintptr_t)arg;
 	tasks_executed[sched_ctx-1] += parallel_code(sched_ctx);
 }
@@ -59,17 +58,13 @@ static void sched_ctx_func(void *descr[] STARPU_ATTRIBUTE_UNUSED, void *arg)
 static struct starpu_codelet sched_ctx_codelet =
 {
 	.cpu_funcs = {sched_ctx_func},
-#ifdef STARPU_DEVEL
-#warning FIXME: cuda_funcs should not need to be defined
-#endif
-	.cuda_funcs = {sched_ctx_func},
 	.model = NULL,
 	.nbuffers = 0,
 	.name = "sched_ctx"
 };
 
 
-int main(int argc, char **argv)
+int main(void)
 {
 	tasks_executed[0] = 0;
 	tasks_executed[1] = 0;
@@ -115,15 +110,18 @@ int main(int argc, char **argv)
 #endif
 
 	if (ncpus == 0) goto enodev;
+#ifdef STARPU_USE_CUDA
 	if (ncuda > 0 && nprocs1 > 1)
 	{
 		procs1[nprocs1-1] = procscuda[0];
 	}
+#endif
 
 	/*create contexts however you want*/
 	unsigned sched_ctx1 = starpu_sched_ctx_create(procs1, nprocs1, "ctx1", 0);
 	unsigned sched_ctx2 = starpu_sched_ctx_create(procs2, nprocs2, "ctx2", 0);
-
+	starpu_sched_ctx_display_workers(sched_ctx1, stderr);
+	starpu_sched_ctx_display_workers(sched_ctx2, stderr);
 	int i;
 	for (i = 0; i < ntasks; i++)
 	{
