@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2015,2017                                CNRS
- * Copyright (C) 2013                                     Université de Bordeaux
- * Copyright (C) 2012                                     Inria
+ * Copyright (C) 2012-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -16,10 +14,16 @@
  * See the GNU Lesser General Public License in COPYING.LGPL for more details.
  */
 
-
 #ifndef __STARPU_SINK_H__
 #define __STARPU_SINK_H__
 
+/**
+   @defgroup API_Sink Sink
+   @{
+*/
+
 void starpu_sink_common_worker(int argc, char **argv);
 
+/** @} */
+
 #endif /* __STARPU_SINK_H__ */
