@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2012,2014                           Université de Bordeaux
- * Copyright (C) 2010-2012,2015                           CNRS
+ * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -24,9 +23,9 @@
 #define xstr(s)        str(s)
 #define STARPU_PLU_STR(name)  xstr(STARPU_PLU(name))
 
-struct starpu_codelet STARPU_PLU(cl11);
-struct starpu_codelet STARPU_PLU(cl12);
-struct starpu_codelet STARPU_PLU(cl21);
-struct starpu_codelet STARPU_PLU(cl22);
+extern struct starpu_codelet STARPU_PLU(cl11);
+extern struct starpu_codelet STARPU_PLU(cl12);
+extern struct starpu_codelet STARPU_PLU(cl21);
+extern struct starpu_codelet STARPU_PLU(cl22);
 
 #endif // __PXLU_KERNELS_H__
