@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011                                     Inria
- * Copyright (C) 2012,2015,2017                           CNRS
- * Copyright (C) 2010-2011,2015                           Université de Bordeaux
+ * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -19,12 +17,11 @@
 #ifndef SOCL_COMMAND_QUEUE_H
 #define SOCL_COMMAND_QUEUE_H
 
-void command_queue_enqueue_ex(
-	cl_command_queue 	cq,		/* Command queue */
-	cl_command		cmd,		/* Command to enqueue */
-	cl_uint			num_events,	/* Number of explicit dependencies */
-	const cl_event *	events		/* Explicit dependencies */
-	);
+void command_queue_enqueue_ex(cl_command_queue 	cq,		/* Command queue */
+			      cl_command		cmd,		/* Command to enqueue */
+			      cl_uint			num_events,	/* Number of explicit dependencies */
+			      const cl_event *	events		/* Explicit dependencies */
+			      );
 
 #define command_queue_enqueue(cq, cmd, num_events, events)\
 	command_queue_enqueue_ex(cq, (cl_command)cmd, num_events, events)
