@@ -1,7 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2015  Université de Bordeaux
- * Copyright (C) 2010, 2011, 2014, 2017  CNRS
+ * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013       Simon Archipoff
+ * Copyright (C) 2013       Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -85,16 +86,16 @@ int starpu_combined_worker_assign_workerid(int nworkers, int workerid_array[])
 	 * safe because this method should only be called when the scheduler
 	 * is being initialized. */
 	new_workerid = basic_worker_count + combined_worker_id;
+	STARPU_ASSERT_MSG(new_workerid < STARPU_NMAXWORKERS, "Too many combined workers for parallel task execution. Please use configure option --enable-maxcpus to increase it beyond the current value %d", STARPU_MAXCPUS);
 	config->topology.ncombinedworkers++;
 
-#if 0
-	fprintf(stderr, "COMBINED WORKERS ");
-	for (i = 0; i < nworkers; i++)
-	{
-		fprintf(stderr, "%d ", workerid_array[i]);
-	}
-	fprintf(stderr, "into worker %d\n", new_workerid);
-#endif
+//	fprintf(stderr, "COMBINED WORKERS ");
+//	for (i = 0; i < nworkers; i++)
+//	{
+//		fprintf(stderr, "%d ", workerid_array[i]);
+//	}
+//	fprintf(stderr, "into worker %d\n", new_workerid);
+
 	for(i = 0; i < nworkers; i++)
 		_starpu_get_worker_struct(workerid_array[i])->combined_workerid = new_workerid;
 
@@ -160,6 +161,8 @@ int starpu_combined_worker_assign_workerid(int nworkers, int workerid_array[])
 #endif
 	}
 
+	starpu_sched_ctx_add_combined_workers(&new_workerid, 1, STARPU_GLOBAL_SCHED_CTX);
+
 	return new_workerid;
 }
 
