@@ -1,9 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2018                                Inria
- * Copyright (C) 2012-2014,2017                           CNRS
- * Copyright (C) 2011-2013,2015-2017,2019                 Université de Bordeaux
- * Copyright (C) 2016                                     Uppsala University
+ * Copyright (C) 2011-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016       Uppsala University
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -20,6 +18,8 @@
 #ifndef __SCHED_CONTEXT_H__
 #define __SCHED_CONTEXT_H__
 
+/** @file */
+
 #include <starpu.h>
 #include <starpu_sched_ctx.h>
 #include <starpu_sched_ctx_hypervisor.h>
@@ -44,39 +44,39 @@
 #define STARPU_NMAXSMS 13
 struct _starpu_sched_ctx
 {
-	/* id of the context used in user mode*/
+	/** id of the context used in user mode*/
 	unsigned id;
 
-	/* boolean indicating whether the scheduling_ctx will be considered for scheduling (1) or not (0)*/
+	/** boolean indicating whether the scheduling_ctx will be considered for scheduling (1) or not (0)*/
 	unsigned do_schedule;
 
-	/* name of context */
+	/** name of context */
 	const char *name;
 
-	/* policy of the context */
+	/** policy of the context */
 	struct starpu_sched_policy *sched_policy;
 
-	/* data necessary for the policy */
+	/** data necessary for the policy */
 	void *policy_data;
 
-	/* pointer for application use */
+	/** pointer for application use */
 	void *user_data;
 
 	struct starpu_worker_collection *workers;
 
-	/* we keep an initial sched which we never delete */
+	/** we keep an initial sched which we never delete */
 	unsigned is_initial_sched;
 
-	/* wait for the tasks submitted to the context to be executed */
+	/** wait for the tasks submitted to the context to be executed */
 	struct _starpu_barrier_counter tasks_barrier;
 
-	/* wait for the tasks ready of the context to be executed */
+	/** wait for the tasks ready of the context to be executed */
 	struct _starpu_barrier_counter ready_tasks_barrier;
 
-	/* amount of ready flops in a context */
+	/** amount of ready flops in a context */
 	double ready_flops;
 
-	/* Iteration number, as advertised by application */
+	/** Iteration number, as advertised by application */
 	long iterations[2];
 	int iteration_level;
 
@@ -86,76 +86,76 @@ struct _starpu_sched_ctx
 	/*ready tasks that couldn't be pushed because the the window of tasks was already full*/
 	struct starpu_task_list waiting_tasks;
 
-	/* min CPUs to execute*/
+	/** min CPUs to execute*/
 	int min_ncpus;
 
-	/* max CPUs to execute*/
+	/** max CPUs to execute*/
 	int max_ncpus;
 
-	/* min GPUs to execute*/
+	/** min GPUs to execute*/
 	int min_ngpus;
 
-	/* max GPUs to execute*/
+	/** max GPUs to execute*/
 	int max_ngpus;
 
-	/* in case we delete the context leave resources to the inheritor*/
+	/** in case we delete the context leave resources to the inheritor*/
 	unsigned inheritor;
 
-	/* indicates whether the application finished submitting tasks
+	/** indicates whether the application finished submitting tasks
 	   to this context*/
 	unsigned finished_submit;
 
-        /* By default we have a binary type of priority: either a task is a priority
+        /** By default we have a binary type of priority: either a task is a priority
          * task (level 1) or it is not (level 0). */
      	int min_priority;
 	int max_priority;
      	int min_priority_is_set;
 	int max_priority_is_set;
 
-	/* hwloc tree structure of workers */
+	/** hwloc tree structure of workers */
 #ifdef STARPU_HAVE_HWLOC
 	hwloc_bitmap_t hwloc_workers_set;
 #endif
 
 #ifdef STARPU_USE_SC_HYPERVISOR
-	/* a structure containing a series of performance counters determining the resize procedure */
+	/** a structure containing a series of performance counters determining the resize procedure */
 	struct starpu_sched_ctx_performance_counters *perf_counters;
 #endif //STARPU_USE_SC_HYPERVISOR
 
-	/* callback called when the context finished executed its submitted tasks */
+	/** callback called when the context finished executed its submitted tasks */
 	void (*close_callback)(unsigned sched_ctx_id, void* args);
 	void *close_args;
-	
-	/* value placing the contexts in their hierarchy */
+
+	/** value placing the contexts in their hierarchy */
 	unsigned hierarchy_level;
 
-	/* if we execute non-StarPU code inside the context 
-	   we have a single master worker that stays awake, 
+	/** if we execute non-StarPU code inside the context
+	   we have a single master worker that stays awake,
 	   if not master is -1 */
 	int main_master;
 
-	/* ctx nesting the current ctx */
+	/** ctx nesting the current ctx */
 	unsigned nesting_sched_ctx;
 
-	/* perf model for the device comb of the ctx */
+	/** perf model for the device comb of the ctx */
 	struct starpu_perfmodel_arch perf_arch;
 
-	/* For parallel workers, say whether it is viewed as sequential or not. This
+	/** For parallel workers, say whether it is viewed as sequential or not. This
 		 is a helper for the prologue code. */
 	unsigned parallel_view;
 
-	/* for ctxs without policy: flag to indicate that we want to get
+	/** for ctxs without policy: flag to indicate that we want to get
 	   the threads to sleep in order to replace them with other threads or leave
 	   them awake & use them in the parallel code*/
 	unsigned awake_workers;
 
-	/* function called when initializing the scheduler */
+	/** function called when initializing the scheduler */
 	void (*init_sched)(unsigned);
 
 	int sub_ctxs[STARPU_NMAXWORKERS];
 	int nsub_ctxs;
 
-	/* nr of SMs assigned to this ctx if we partition gpus*/
+	/** nr of SMs assigned to this ctx if we partition gpus*/
 	int nsms;
 	int sms_start_idx;
 	int sms_end_idx;
@@ -166,7 +166,7 @@ struct _starpu_sched_ctx
 	starpu_pthread_t lock_write_owner;
 };
 
-/* per-worker list of deferred ctx_change ops */
+/** per-worker list of deferred ctx_change ops */
 LIST_TYPE(_starpu_ctx_change,
 	int sched_ctx_id;
 	int op;
@@ -178,26 +178,26 @@ LIST_TYPE(_starpu_ctx_change,
 
 struct _starpu_machine_config;
 
-/* init sched_ctx_id of all contextes*/
+/** init sched_ctx_id of all contextes*/
 void _starpu_init_all_sched_ctxs(struct _starpu_machine_config *config);
 
-/* allocate all structures belonging to a context */
+/** allocate all structures belonging to a context */
 struct _starpu_sched_ctx*  _starpu_create_sched_ctx(struct starpu_sched_policy *policy, int *workerid, int nworkerids, unsigned is_init_sched, const char *sched_name,
 						    int min_prio_set, int min_prio,
 						    int max_prio_set, int max_prio, unsigned awake_workers, void (*sched_policy_init)(unsigned), void *user_data,
 							int nsub_ctxs, int *sub_ctxs, int nsms);
 
-/* delete all sched_ctx */
+/** delete all sched_ctx */
 void _starpu_delete_all_sched_ctxs();
 
-/* This function waits until all the tasks that were already submitted to a specific
+/** This function waits until all the tasks that were already submitted to a specific
  * context have been executed. */
 int _starpu_wait_for_all_tasks_of_sched_ctx(unsigned sched_ctx_id);
 
-/* This function waits until at most n tasks are still submitted. */
+/** This function waits until at most n tasks are still submitted. */
 int _starpu_wait_for_n_submitted_tasks_of_sched_ctx(unsigned sched_ctx_id, unsigned n);
 
-/* In order to implement starpu_wait_for_all_tasks_of_ctx, we keep track of the number of
+/** In order to implement starpu_wait_for_all_tasks_of_ctx, we keep track of the number of
  * task currently submitted to the context */
 void _starpu_decrement_nsubmitted_tasks_of_sched_ctx(unsigned sched_ctx_id);
 void _starpu_increment_nsubmitted_tasks_of_sched_ctx(unsigned sched_ctx_id);
@@ -208,33 +208,33 @@ void _starpu_decrement_nready_tasks_of_sched_ctx(unsigned sched_ctx_id, double r
 unsigned _starpu_increment_nready_tasks_of_sched_ctx(unsigned sched_ctx_id, double ready_flops, struct starpu_task *task);
 int _starpu_wait_for_no_ready_of_sched_ctx(unsigned sched_ctx_id);
 
-/* Return the corresponding index of the workerid in the ctx table */
+/** Return the corresponding index of the workerid in the ctx table */
 int _starpu_get_index_in_ctx_of_workerid(unsigned sched_ctx, unsigned workerid);
 
-/* Get the mutex corresponding to the global workerid */
+/** Get the mutex corresponding to the global workerid */
 starpu_pthread_mutex_t *_starpu_get_sched_mutex(struct _starpu_sched_ctx *sched_ctx, int worker);
 
-/* Get workers belonging to a certain context, it returns the number of workers
+/** Get workers belonging to a certain context, it returns the number of workers
  take care: no mutex taken, the list of workers might not be updated */
 int _starpu_get_workers_of_sched_ctx(unsigned sched_ctx_id, int *pus, enum starpu_worker_archtype arch);
 
-/* Let the worker know it does not belong to the context and that
+/** Let the worker know it does not belong to the context and that
    it should stop poping from it */
 void _starpu_worker_gets_out_of_ctx(unsigned sched_ctx_id, struct _starpu_worker *worker);
 
-/* Check if the worker belongs to another sched_ctx */
+/** Check if the worker belongs to another sched_ctx */
 unsigned _starpu_worker_belongs_to_a_sched_ctx(int workerid, unsigned sched_ctx_id);
 
-/* indicates wheather this worker should go to sleep or not 
+/** indicates wheather this worker should go to sleep or not
    (if it is the last one awake in a context he should better keep awake) */
 unsigned _starpu_sched_ctx_last_worker_awake(struct _starpu_worker *worker);
 
-/* If starpu_sched_ctx_set_context() has been called, returns the context
+/** If starpu_sched_ctx_set_context() has been called, returns the context
  * id set by its last call, or the id of the initial context */
 unsigned _starpu_sched_ctx_get_current_context();
 
-/* verify how many workers can execute a certain task */
-int _starpu_nworkers_able_to_execute_task(struct starpu_task *task, struct _starpu_sched_ctx *sched_ctx);
+/** verify that some worker can execute a certain task */
+int _starpu_workers_able_to_execute_task(struct starpu_task *task, struct _starpu_sched_ctx *sched_ctx);
 
 void _starpu_fetch_tasks_from_empty_ctx_list(struct _starpu_sched_ctx *sched_ctx);
 
@@ -242,14 +242,14 @@ unsigned _starpu_sched_ctx_allow_hypervisor(unsigned sched_ctx_id);
 
 struct starpu_perfmodel_arch * _starpu_sched_ctx_get_perf_archtype(unsigned sched_ctx);
 #ifdef STARPU_USE_SC_HYPERVISOR
-/* Notifies the hypervisor that a tasks was poped from the workers' list */
+/** Notifies the hypervisor that a tasks was poped from the workers' list */
 void _starpu_sched_ctx_post_exec_task_cb(int workerid, struct starpu_task *task, size_t data_size, uint32_t footprint);
 
 #endif //STARPU_USE_SC_HYPERVISOR
 
 void starpu_sched_ctx_add_combined_workers(int *combined_workers_to_add, unsigned n_combined_workers_to_add, unsigned sched_ctx_id);
 
-/* if the worker is the master of a parallel context, and the job is meant to be executed on this parallel context, return a pointer to the context */
+/** if the worker is the master of a parallel context, and the job is meant to be executed on this parallel context, return a pointer to the context */
 struct _starpu_sched_ctx *__starpu_sched_ctx_get_sched_ctx_for_worker_and_job(struct _starpu_worker *worker, struct _starpu_job *j);
 
 #define _starpu_sched_ctx_get_sched_ctx_for_worker_and_job(w,j) \
@@ -314,7 +314,7 @@ static inline unsigned _starpu_sched_ctx_worker_is_master_for_child_ctx(unsigned
 	return 0;
 }
 
-/* Go through the list of deferred ctx changes of the current worker and apply
+/** Go through the list of deferred ctx changes of the current worker and apply
  * any ctx change operation found until the list is empty */
 void _starpu_worker_apply_deferred_ctx_changes(void);
 #endif // __SCHED_CONTEXT_H__
