@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011,2013-2014                           Inria
- * Copyright (C) 2009-2016                                Université de Bordeaux
- * Copyright (C) 2010-2017                                CNRS
+ * Copyright (C) 2009-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -19,20 +17,22 @@
 #ifndef __CORE_TASK_H__
 #define __CORE_TASK_H__
 
+/** @file */
+
 #include <starpu.h>
 #include <common/config.h>
 #include <core/jobs.h>
 
-/* Internal version of starpu_task_destroy: don't check task->destroy flag */
+/** Internal version of starpu_task_destroy: don't check task->destroy flag */
 void _starpu_task_destroy(struct starpu_task *task);
 
 #ifdef STARPU_OPENMP
-/* Test for the termination of the task.
+/** Test for the termination of the task.
  * Call starpu_task_destroy if required and the task is terminated. */
 int _starpu_task_test_termination(struct starpu_task *task);
 #endif
 
-/* A pthread key is used to store the task currently executed on the thread.
+/** A pthread key is used to store the task currently executed on the thread.
  * _starpu_task_init initializes this pthread key and
  * _starpu_set_current_task updates its current value. */
 void _starpu_task_init(void);
@@ -47,12 +47,12 @@ int _starpu_task_submit_nodeps(struct starpu_task *task);
 
 void _starpu_task_declare_deps_array(struct starpu_task *task, unsigned ndeps, struct starpu_task *task_array[], int check);
 
-/* Returns the job structure (which is the internal data structure associated
+/** Returns the job structure (which is the internal data structure associated
  * to a task). */
 static inline struct _starpu_job *_starpu_get_job_associated_to_task(struct starpu_task *task)
 {
 	STARPU_ASSERT(task);
-	struct _starpu_job *job = task->starpu_private;
+	struct _starpu_job *job = (struct _starpu_job *) task->starpu_private;
 
 	if (STARPU_UNLIKELY(!job))
 	{
@@ -63,7 +63,7 @@ static inline struct _starpu_job *_starpu_get_job_associated_to_task(struct star
 	return job;
 }
 
-/* Submits starpu internal tasks to the initial context */
+/** Submits starpu internal tasks to the initial context */
 int _starpu_task_submit_internally(struct starpu_task *task);
 
 int _starpu_handle_needs_conversion_task(starpu_data_handle_t handle,
@@ -73,7 +73,7 @@ _starpu_handle_needs_conversion_task_for_arch(starpu_data_handle_t handle,
 				     enum starpu_node_kind node_kind);
 
 #ifdef STARPU_OPENMP
-/* Prepare the current task for accepting new dependencies before becoming a continuation. */
+/** Prepare the current task for accepting new dependencies before becoming a continuation. */
 void _starpu_task_prepare_for_continuation_ext(unsigned continuation_resubmit,
 		void (*continuation_callback_on_sleep)(void *arg), void *continuation_callback_on_sleep_arg);
 
@@ -111,9 +111,9 @@ static inline starpu_mic_func_t _starpu_task_get_mic_nth_implementation(struct s
 	return cl->mic_funcs[nimpl];
 }
 
-static inline starpu_scc_func_t _starpu_task_get_scc_nth_implementation(struct starpu_codelet *cl, unsigned nimpl)
+static inline starpu_mpi_ms_func_t _starpu_task_get_mpi_ms_nth_implementation(struct starpu_codelet *cl, unsigned nimpl)
 {
-	return cl->scc_funcs[nimpl];
+	return cl->mpi_ms_funcs[nimpl];
 }
 
 static inline const char *_starpu_task_get_cpu_name_nth_implementation(struct starpu_codelet *cl, unsigned nimpl)
@@ -130,4 +130,10 @@ void _starpu_watchdog_shutdown(void);
 int _starpu_task_wait_for_all_and_return_nb_waited_tasks(void);
 int _starpu_task_wait_for_all_in_ctx_and_return_nb_waited_tasks(unsigned sched_ctx);
 
+
+#ifdef BUILDING_STARPU
+LIST_CREATE_TYPE_NOSTRUCT(starpu_task, prev, next);
+PRIO_LIST_CREATE_TYPE(starpu_task, priority);
+#endif
+
 #endif // __CORE_TASK_H__
