@@ -1,10 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2017                                Inria
- * Copyright (C) 2010-2018                                Université de Bordeaux
- * Copyright (C) 2010-2017, 2019                          CNRS
- * Copyright (C) 2013                                     Thibaut Lambert
- * Copyright (C) 2011                                     Télécom-SudParis
+ * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2011       Télécom-SudParis
+ * Copyright (C) 2013       Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -30,8 +28,6 @@
 #include <core/debug.h>
 #include <core/task.h>
 
-#define BACKOFF_MAX 32  /* TODO : use parameter to define them */
-#define BACKOFF_MIN 1
 
 void _starpu_driver_start_job(struct _starpu_worker *worker, struct _starpu_job *j, struct starpu_perfmodel_arch* perf_arch, int rank, int profiling)
 {
@@ -281,8 +277,11 @@ void _starpu_driver_update_job_feedback(struct _starpu_job *j, struct _starpu_wo
 
 static void _starpu_worker_set_status_scheduling(int workerid)
 {
-	if (_starpu_worker_get_status(workerid) != STATUS_SLEEPING
-		&& _starpu_worker_get_status(workerid) != STATUS_SCHEDULING)
+	if (_starpu_worker_get_status(workerid) == STATUS_SLEEPING)
+	{
+		_starpu_worker_set_status(workerid, STATUS_SLEEPING_SCHEDULING);
+	}
+	else if (_starpu_worker_get_status(workerid) != STATUS_SCHEDULING)
 	{
 		_STARPU_TRACE_WORKER_SCHEDULING_START;
 		_starpu_worker_set_status(workerid, STATUS_SCHEDULING);
@@ -291,7 +290,11 @@ static void _starpu_worker_set_status_scheduling(int workerid)
 
 static void _starpu_worker_set_status_scheduling_done(int workerid)
 {
-	if (_starpu_worker_get_status(workerid) == STATUS_SCHEDULING)
+	if (_starpu_worker_get_status(workerid) == STATUS_SLEEPING_SCHEDULING)
+	{
+		_starpu_worker_set_status(workerid, STATUS_SLEEPING);
+	}
+	else if (_starpu_worker_get_status(workerid) == STATUS_SCHEDULING)
 	{
 		_STARPU_TRACE_WORKER_SCHEDULING_END;
 		_starpu_worker_set_status(workerid, STATUS_UNKNOWN);
@@ -302,8 +305,11 @@ static void _starpu_worker_set_status_sleeping(int workerid)
 {
 	if (_starpu_worker_get_status(workerid) != STATUS_SLEEPING)
 	{
-		_STARPU_TRACE_WORKER_SLEEP_START;
-		_starpu_worker_restart_sleeping(workerid);
+		if (_starpu_worker_get_status(workerid) != STATUS_SLEEPING_SCHEDULING)
+		{
+			_STARPU_TRACE_WORKER_SLEEP_START;
+			_starpu_worker_restart_sleeping(workerid);
+		}
 		_starpu_worker_set_status(workerid, STATUS_SLEEPING);
 	}
 
@@ -325,7 +331,7 @@ static void _starpu_exponential_backoff(struct _starpu_worker *worker)
 {
 	int delay = worker->spinning_backoff;
 
-	if (worker->spinning_backoff < BACKOFF_MAX)
+	if (worker->spinning_backoff < worker->config->conf.driver_spinning_backoff_max)
 		worker->spinning_backoff<<=1;
 
 	while(delay--)
@@ -455,7 +461,7 @@ struct starpu_task *_starpu_get_worker_task(struct _starpu_worker *worker, int w
 	{
 		_starpu_worker_set_status_sleeping(workerid);
 	}
-	worker->spinning_backoff = BACKOFF_MIN;
+	worker->spinning_backoff = worker->config->conf.driver_spinning_backoff_min;
 
 	_starpu_worker_leave_sched_op(worker);
 	STARPU_PTHREAD_COND_BROADCAST(&worker->sched_cond);
@@ -654,7 +660,7 @@ int _starpu_get_multi_worker_task(struct _starpu_worker *workers, struct starpu_
 	}
 
 	_starpu_worker_set_status_wakeup(workerid);
-	worker->spinning_backoff = BACKOFF_MIN;
+	worker->spinning_backoff = worker->config->conf.driver_spinning_backoff_min;
 #endif /* !STARPU_SIMGRID */
 
 	_starpu_worker_leave_sched_op(&workers[0]);
