@@ -1,9 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011                                     Inria
- * Copyright (C) 2010-2015                                Université de Bordeaux
- * Copyright (C) 2011-2013,2015,2017                      CNRS
- * Copyright (C) 2013                                     Thibaut Lambert
+ * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013       Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -20,10 +18,10 @@
 #include <starpu.h>
 #include <common/config.h>
 #include <core/task.h>
+#include <core/workers.h>
 #include <datawizard/datawizard.h>
 #include <util/starpu_data_cpy.h>
 #include <starpu_mic.h>
-#include <starpu_scc.h>
 
 static void common_data_cpy_func(void *descr[], void *cl_arg)
 {
@@ -32,7 +30,7 @@ static void common_data_cpy_func(void *descr[], void *cl_arg)
 	const struct starpu_data_interface_ops *interface_ops = _starpu_data_interface_get_ops(interface_id);
 	const struct starpu_data_copy_methods *copy_methods = interface_ops->copy_methods;
 
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 	enum starpu_worker_archtype type = starpu_worker_get_type(workerid);
 	unsigned memory_node = starpu_worker_get_memory_node(workerid);
 
@@ -48,13 +46,23 @@ static void common_data_cpy_func(void *descr[], void *cl_arg)
 				return;
 			}
 			break;
+#ifdef STARPU_USE_CUDA
 		case STARPU_CUDA_WORKER:
-			if (copy_methods->cuda_to_cuda)
+		{
+			cudaStream_t stream = starpu_cuda_get_local_stream();
+			if (copy_methods->cuda_to_cuda_async)
+			{
+				copy_methods->cuda_to_cuda_async(src_interface, memory_node, dst_interface, memory_node, stream);
+				return;
+			}
+			else if (copy_methods->cuda_to_cuda)
 			{
 				copy_methods->cuda_to_cuda(src_interface, memory_node, dst_interface, memory_node);
 				return;
 			}
 			break;
+		}
+#endif
 		case STARPU_OPENCL_WORKER:
 			if (copy_methods->opencl_to_opencl)
 			{
@@ -103,20 +111,6 @@ static starpu_mic_kernel_t mic_cpy_func()
 #endif
 }
 
-static starpu_scc_kernel_t scc_cpy_func()
-{
-#ifdef STARPU_USE_SCC
-	static starpu_scc_func_symbol_t scc_symbol = NULL;
-	if (scc_symbol == NULL)
-		starpu_scc_register_kernel(&scc_symbol, "mp_cpy_kernel");
-
-	return starpu_scc_get_kernel(scc_symbol);
-#else
-	STARPU_ABORT();
-	return NULL;
-#endif
-}
-
 struct starpu_perfmodel copy_model =
 {
 	.type = STARPU_HISTORY_BASED,
@@ -125,12 +119,11 @@ struct starpu_perfmodel copy_model =
 
 static struct starpu_codelet copy_cl =
 {
-	.where = STARPU_CPU|STARPU_CUDA|STARPU_OPENCL|STARPU_MIC|STARPU_SCC,
+	.where = STARPU_CPU|STARPU_CUDA|STARPU_OPENCL|STARPU_MIC,
 	.cpu_funcs = {common_data_cpy_func},
 	.cuda_funcs = {common_data_cpy_func},
 	.opencl_funcs = {common_data_cpy_func},
 	.mic_funcs = {mic_cpy_func},
-	.scc_funcs = {scc_cpy_func},
 	.nbuffers = 2,
 	.modes = {STARPU_W, STARPU_R},
 	.model = &copy_model
@@ -165,6 +158,7 @@ int _starpu_data_cpy(starpu_data_handle_t dst_handle, starpu_data_handle_t src_h
 	task->callback_func = callback_func;
 	task->callback_arg = callback_arg;
 
+	/* FIXME: priority!! */
 	STARPU_TASK_SET_HANDLE(task, dst_handle, 0);
 	STARPU_TASK_SET_HANDLE(task, src_handle, 1);
 
