@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2013  Université de Bordeaux 1
- * Copyright (C) 2010, 2011, 2012, 2013  Centre National de la Recherche Scientifique
+ * Copyright (C) 2009-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -89,7 +88,7 @@ STARPUFFT(fft1_1d_plan_gpu)(void *args)
 {
 	STARPUFFT(plan) plan = args;
 	int n2 = plan->n2[0];
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 	cufftResult cures;
 
 	cures = cufftPlan1d(&plan->plans[workerid].plan1_cuda, n2, _CUFFT_C2C, 1);
@@ -113,7 +112,7 @@ STARPUFFT(fft1_1d_kernel_gpu)(void *descr[], void *_args)
 	_cufftComplex * restrict out = (_cufftComplex *)STARPU_VECTOR_GET_PTR(descr[1]);
 	const _cufftComplex * restrict roots = (_cufftComplex *)STARPU_VECTOR_GET_PTR(descr[2]);
 
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 
 	task_per_worker[workerid]++;
 
@@ -137,7 +136,7 @@ STARPUFFT(fft2_1d_plan_gpu)(void *args)
 	int n2 = plan->n2[0];
 	int n3 = n2/DIV_1D;
 	cufftResult cures;
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 
 	cures = cufftPlan1d(&plan->plans[workerid].plan2_cuda, n1, _CUFFT_C2C, n3);
 	if (cures != CUFFT_SUCCESS)
@@ -157,7 +156,7 @@ STARPUFFT(fft2_1d_kernel_gpu)(void *descr[], void *_args)
 	_cufftComplex * restrict in = (_cufftComplex *)STARPU_VECTOR_GET_PTR(descr[0]);
 	_cufftComplex * restrict out = (_cufftComplex *)STARPU_VECTOR_GET_PTR(descr[1]);
 
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 
 	task_per_worker[workerid]++;
 
@@ -205,7 +204,7 @@ STARPUFFT(fft1_1d_kernel_cpu)(void *descr[], void *_args)
 	int i = args->i;
 	int j;
 	int n2 = plan->n2[0];
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 
 	task_per_worker[workerid]++;
 
@@ -259,7 +258,7 @@ STARPUFFT(fft2_1d_kernel_cpu)(void *descr[], void *_args)
 	struct STARPUFFT(args) *args = _args;
 	STARPUFFT(plan) plan = args->plan;
 	/* int jj = args->jj; */
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 
 	task_per_worker[workerid]++;
 
@@ -332,9 +331,9 @@ static struct starpu_codelet STARPUFFT(twist1_1d_codelet) = {
 #endif
 		STARPU_CPU,
 #ifdef __STARPU_USE_CUDA
-	.cuda_funcs = {STARPUFFT(twist1_1d_kernel_gpu), NULL},
+	.cuda_funcs = {STARPUFFT(twist1_1d_kernel_gpu)},
 #endif
-	.cpu_funcs = {STARPUFFT(twist1_1d_kernel_cpu), NULL},
+	.cpu_funcs = {STARPUFFT(twist1_1d_kernel_cpu)},
 	CAN_EXECUTE
 	.model = &STARPUFFT(twist1_1d_model),
 	.nbuffers = 2,
@@ -352,10 +351,10 @@ static struct starpu_codelet STARPUFFT(fft1_1d_codelet) = {
 #endif
 		0,
 #ifdef __STARPU_USE_CUDA
-	.cuda_funcs = {STARPUFFT(fft1_1d_kernel_gpu), NULL},
+	.cuda_funcs = {STARPUFFT(fft1_1d_kernel_gpu)},
 #endif
 #ifdef STARPU_HAVE_FFTW
-	.cpu_funcs = {STARPUFFT(fft1_1d_kernel_cpu), NULL},
+	.cpu_funcs = {STARPUFFT(fft1_1d_kernel_cpu)},
 #endif
 	CAN_EXECUTE
 	.model = &STARPUFFT(fft1_1d_model),
@@ -366,7 +365,7 @@ static struct starpu_codelet STARPUFFT(fft1_1d_codelet) = {
 
 static struct starpu_codelet STARPUFFT(twist2_1d_codelet) = {
 	.where = STARPU_CPU,
-	.cpu_funcs = {STARPUFFT(twist2_1d_kernel_cpu), NULL},
+	.cpu_funcs = {STARPUFFT(twist2_1d_kernel_cpu)},
 	CAN_EXECUTE
 	.model = &STARPUFFT(twist2_1d_model),
 	.nbuffers = 1,
@@ -384,10 +383,10 @@ static struct starpu_codelet STARPUFFT(fft2_1d_codelet) = {
 #endif
 		0,
 #ifdef __STARPU_USE_CUDA
-	.cuda_funcs = {STARPUFFT(fft2_1d_kernel_gpu), NULL},
+	.cuda_funcs = {STARPUFFT(fft2_1d_kernel_gpu)},
 #endif
 #ifdef STARPU_HAVE_FFTW
-	.cpu_funcs = {STARPUFFT(fft2_1d_kernel_cpu), NULL},
+	.cpu_funcs = {STARPUFFT(fft2_1d_kernel_cpu)},
 #endif
 	CAN_EXECUTE
 	.model = &STARPUFFT(fft2_1d_model),
@@ -398,7 +397,7 @@ static struct starpu_codelet STARPUFFT(fft2_1d_codelet) = {
 
 static struct starpu_codelet STARPUFFT(twist3_1d_codelet) = {
 	.where = STARPU_CPU,
-	.cpu_funcs = {STARPUFFT(twist3_1d_kernel_cpu), NULL},
+	.cpu_funcs = {STARPUFFT(twist3_1d_kernel_cpu)},
 	CAN_EXECUTE
 	.model = &STARPUFFT(twist3_1d_model),
 	.nbuffers = 1,
@@ -420,7 +419,7 @@ STARPUFFT(fft_1d_plan_gpu)(void *args)
 	STARPUFFT(plan) plan = args;
 	cufftResult cures;
 	int n = plan->n[0];
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 
 	cures = cufftPlan1d(&plan->plans[workerid].plan_cuda, n, _CUFFT_C2C, 1);
 	if (cures != CUFFT_SUCCESS)
@@ -439,7 +438,7 @@ STARPUFFT(fft_1d_kernel_gpu)(void *descr[], void *args)
 	_cufftComplex * restrict in = (_cufftComplex *)STARPU_VECTOR_GET_PTR(descr[0]);
 	_cufftComplex * restrict out = (_cufftComplex *)STARPU_VECTOR_GET_PTR(descr[1]);
 
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 
 	task_per_worker[workerid]++;
 
@@ -457,7 +456,7 @@ static void
 STARPUFFT(fft_1d_kernel_cpu)(void *descr[], void *_args)
 {
 	STARPUFFT(plan) plan = _args;
-	int workerid = starpu_worker_get_id();
+	int workerid = starpu_worker_get_id_check();
 
 	task_per_worker[workerid]++;
 
@@ -483,10 +482,10 @@ static struct starpu_codelet STARPUFFT(fft_1d_codelet) = {
 #endif
 		0,
 #ifdef __STARPU_USE_CUDA
-	.cuda_funcs = {STARPUFFT(fft_1d_kernel_gpu), NULL},
+	.cuda_funcs = {STARPUFFT(fft_1d_kernel_gpu)},
 #endif
 #ifdef STARPU_HAVE_FFTW
-	.cpu_funcs = {STARPUFFT(fft_1d_kernel_cpu), NULL},
+	.cpu_funcs = {STARPUFFT(fft_1d_kernel_cpu)},
 #endif
 	CAN_EXECUTE
 	.model = &STARPUFFT(fft_1d_model),
@@ -508,7 +507,7 @@ static struct starpu_codelet STARPUFFT(fft_1d_codelet) = {
 STARPUFFT(plan)
 STARPUFFT(plan_dft_1d)(int n, int sign, unsigned flags)
 {
-	int workerid;
+	unsigned workerid;
 	int n1 = DIV_1D;
 	int n2 = n / n1;
 	int n3;
@@ -658,9 +657,9 @@ if (PARALLEL) {
 		plan->fft1_args[z].i = i;
 
 		/* Register the twisted1 buffer of size n2. */
-		starpu_vector_data_register(&plan->twisted1_handle[z], 0, (uintptr_t) &plan->twisted1[z*plan->totsize2], plan->totsize2, sizeof(*plan->twisted1));
+		starpu_vector_data_register(&plan->twisted1_handle[z], STARPU_MAIN_RAM, (uintptr_t) &plan->twisted1[z*plan->totsize2], plan->totsize2, sizeof(*plan->twisted1));
 		/* Register the fft1 buffer of size n2. */
-		starpu_vector_data_register(&plan->fft1_handle[z], 0, (uintptr_t) &plan->fft1[z*plan->totsize2], plan->totsize2, sizeof(*plan->fft1));
+		starpu_vector_data_register(&plan->fft1_handle[z], STARPU_MAIN_RAM, (uintptr_t) &plan->fft1[z*plan->totsize2], plan->totsize2, sizeof(*plan->fft1));
 
 		/* We'll need the result of fft1 on the CPU for the second
 		 * twist anyway, so tell starpu to not keep the fft1 buffer in
@@ -717,8 +716,8 @@ if (PARALLEL) {
 		plan->fft2_args[z].jj = jj;
 
 		/* Register n3 twisted2 buffers of size n1 */
-		starpu_vector_data_register(&plan->twisted2_handle[z], 0, (uintptr_t) &plan->twisted2[z*plan->totsize4], plan->totsize4, sizeof(*plan->twisted2));
-		starpu_vector_data_register(&plan->fft2_handle[z], 0, (uintptr_t) &plan->fft2[z*plan->totsize4], plan->totsize4, sizeof(*plan->fft2));
+		starpu_vector_data_register(&plan->twisted2_handle[z], STARPU_MAIN_RAM, (uintptr_t) &plan->twisted2[z*plan->totsize4], plan->totsize4, sizeof(*plan->twisted2));
+		starpu_vector_data_register(&plan->fft2_handle[z], STARPU_MAIN_RAM, (uintptr_t) &plan->fft2[z*plan->totsize4], plan->totsize4, sizeof(*plan->fft2));
 
 		/* We'll need the result of fft2 on the CPU for the third
 		 * twist anyway, so tell starpu to not keep the fft2 buffer in
@@ -848,7 +847,7 @@ if (PARALLEL) {
 static void
 STARPUFFT(free_1d_tags)(STARPUFFT(plan) plan)
 {
-	unsigned i;
+	int i;
 	int n1 = plan->n1[0];
 
 	if (!PARALLEL)
