@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012-2013                                Inria
- * Copyright (C) 2012-2013,2015,2017                      CNRS
- * Copyright (C) 2011-2016                                Université de Bordeaux
+ * Copyright (C) 2011-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -32,8 +30,9 @@ static starpu_data_handle_t handle;
 
 #ifdef STARPU_USE_OPENCL
 /* dummy OpenCL implementation */
-static void increment_opencl_kernel(void *descr[], void *cl_arg STARPU_ATTRIBUTE_UNUSED)
+static void increment_opencl_kernel(void *descr[], void *cl_arg)
 {
+	(void)cl_arg;
 	cl_mem d_token = (cl_mem)STARPU_VARIABLE_GET_PTR(descr[0]);
 	unsigned h_token;
 
@@ -48,8 +47,9 @@ static void increment_opencl_kernel(void *descr[], void *cl_arg STARPU_ATTRIBUTE
 
 
 #ifdef STARPU_USE_CUDA
-static void increment_cuda_kernel(void *descr[], void *arg)
+static void increment_cuda_kernel(void *descr[], void *cl_arg)
 {
+	(void)cl_arg;
 	unsigned *tokenptr = (unsigned *)STARPU_VARIABLE_GET_PTR(descr[0]);
 	unsigned host_token;
 
@@ -63,8 +63,9 @@ static void increment_cuda_kernel(void *descr[], void *arg)
 }
 #endif
 
-void increment_cpu_kernel(void *descr[], void *arg)
+void increment_cpu_kernel(void *descr[], void *cl_arg)
 {
+	(void)cl_arg;
 	unsigned *tokenptr = (unsigned *)STARPU_VARIABLE_GET_PTR(descr[0]);
 	*tokenptr = *tokenptr + 1;
 }
@@ -85,7 +86,7 @@ static struct starpu_codelet increment_cl =
 	.modes = {STARPU_RW}
 };
 
-int main(int argc, char **argv)
+int main(void)
 {
 	int ret;
 
