@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009, 2010  Université de Bordeaux 1
- * Copyright (C) 2010  Centre National de la Recherche Scientifique
+ * Copyright (C) 2009-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -20,28 +19,37 @@
 #include <errno.h>
 #include <starpu.h>
 #include <stdlib.h>
+#include "../helper.h"
+
+/*
+ * Test executing a function on all workers
+ */
 
 void func(void *arg)
 {
-	int *ptr = arg;
+	int *ptr = (int *) arg;
 	STARPU_ASSERT(*ptr == 0x42);
 }
 
 int main(int argc, char **argv)
 {
-	starpu_init(NULL);
+	int ret;
+
+	ret = starpu_initialize(NULL, &argc, &argv);
+	if (ret == -ENODEV) return STARPU_TEST_SKIPPED;
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_init");
 
 	int arg = 0x42;
 
 	starpu_execute_on_each_worker(func, &arg, STARPU_CPU|STARPU_CUDA|STARPU_OPENCL);
 
 	starpu_execute_on_each_worker(func, &arg, STARPU_CPU);
-	
+
 	starpu_execute_on_each_worker(func, &arg, STARPU_CUDA);
 
         starpu_execute_on_each_worker(func, &arg, STARPU_OPENCL);
 
 	starpu_shutdown();
 
-	return 0;
+	return EXIT_SUCCESS;
 }
