@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010, 2016  Université de Bordeaux
- * Copyright (C) 2010, 2011, 2012, 2013  CNRS
+ * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -15,7 +14,6 @@
  * See the GNU Lesser General Public License in COPYING.LGPL for more details.
  */
 
-#include <config.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <starpu.h>
@@ -33,6 +31,7 @@ static unsigned ntasks = 65536;
 
 void check_task_func(void *descr[], void *arg)
 {
+	(void)descr;
 	/* We check that the returned task is valid from the callback */
 	struct starpu_task *task = (struct starpu_task *) arg;
 	STARPU_ASSERT(task == starpu_task_get_current());
