@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2012, 2014-2015, 2017  Université de Bordeaux
+ * Copyright (C) 2011-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -14,10 +14,10 @@
  * See the GNU Lesser General Public License in COPYING.LGPL for more details.
  */
 
-#include <config.h>
 #include <stdio.h>
 #include <starpu.h>
 #include <starpu_scheduler.h>
+#include <common/config.h>
 
 #define PROGNAME "starpu_machine_display"
 
@@ -37,25 +37,6 @@ static void usage()
 	fprintf(stderr, "Report bugs to <%s>.\n", PACKAGE_BUGREPORT);
 }
 
-static void display_worker_names(enum starpu_worker_archtype type)
-{
-	int nworkers = starpu_worker_get_count_by_type(type);
-	if (!nworkers)
-		return;
-	STARPU_ASSERT(nworkers>0);
-
-	int ids[nworkers];
-	starpu_worker_get_ids_by_type(type, ids, nworkers);
-
-	int i;
-	for (i = 0; i < nworkers; i++)
-	{
-		char name[256];
-		starpu_worker_get_name(ids[i], name, 256);
-		fprintf(stdout, "\t\t%s\n", name);
-	}
-}
-
 static void display_combined_worker(unsigned workerid)
 {
 	int worker_size;
@@ -157,29 +138,16 @@ int main(int argc, char **argv)
 		return 0;
 	}
 
-	unsigned ncpu = starpu_cpu_worker_get_count();
-	unsigned ncuda = starpu_cuda_worker_get_count();
-	unsigned nopencl = starpu_opencl_worker_get_count();
-
-#ifdef STARPU_USE_MIC
-	unsigned nmicdevs = starpu_mic_device_get_count();
-	unsigned nmiccores = starpu_mic_worker_get_count();
-#endif
-
 	fprintf(stdout, "StarPU has found :\n");
 
-	fprintf(stdout, "\t%u CPU threads\n", ncpu);
-	display_worker_names(STARPU_CPU_WORKER);
-
-	fprintf(stdout, "\t%u CUDA devices\n", ncuda);
-	display_worker_names(STARPU_CUDA_WORKER);
-
-	fprintf(stdout, "\t%u OpenCL devices\n", nopencl);
-	display_worker_names(STARPU_OPENCL_WORKER);
-
+	starpu_worker_display_names(stdout, STARPU_CPU_WORKER);
+	starpu_worker_display_names(stdout, STARPU_CUDA_WORKER);
+	starpu_worker_display_names(stdout, STARPU_OPENCL_WORKER);
 #ifdef STARPU_USE_MIC
-	fprintf(stdout, "\t%u MIC cores (from %u devices)\n", nmiccores, nmicdevs);
-	display_worker_names(STARPU_MIC_WORKER);
+	starpu_worker_display_names(stdout, STARPU_MIC_WORKER);
+#endif
+#ifdef STARPU_USE_MPI_MASTER_SLAVE
+	starpu_worker_display_names(stdout, STARPU_MPI_MS_WORKER);
 #endif
 
 	display_all_combined_workers();
@@ -189,7 +157,7 @@ int main(int argc, char **argv)
 		fprintf(stdout, "\ntopology ... (hwloc logical indexes)\n");
 		starpu_topology_print(stdout);
 
-		fprintf(stdout, "\nbandwidth and latency ...\n");
+		fprintf(stdout, "\nbandwidth (MB/s) and latency (us)...\n");
 		starpu_bus_print_bandwidth(stdout);
 
 		starpu_shutdown();
