@@ -1,9 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2017                                     Erwan Leria
- * Copyright (C) 2018                                     Inria
- * Copyright (C) 2017,2018,2019                           CNRS
- * Copyright (C) 2016-2019                                Université de Bordeaux
+ * Copyright (C) 2016-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2017       Erwan Leria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -66,7 +64,7 @@ static long submitorder = -1;
 static starpu_tag_t tag;
 static int workerid;
 static uint32_t footprint;
-static double flops;
+static double flops, total_flops = 0.;
 
 static double startTime; //start time (The instant when the task starts)
 static double endTime; //end time (The instant when the task ends)
@@ -182,15 +180,30 @@ double arch_cost_function(struct starpu_task *task, struct starpu_perfmodel_arch
 /* End of settings */
 
 static unsigned long nexecuted_tasks;
-void dumb_kernel(void *buffers[], void *args) {
+void dumb_kernel(void *buffers[], void *args)
+{
 	(void) buffers;
 	(void) args;
 	nexecuted_tasks++;
 	if (!(nexecuted_tasks % 1000))
 	{
-		printf("\rExecuted task %lu...", nexecuted_tasks);
+		fprintf(stderr, "\rExecuted task %lu...", nexecuted_tasks);
 		fflush(stdout);
 	}
+
+	unsigned this_worker = starpu_worker_get_id_check();
+	struct starpu_perfmodel_arch *perf_arch = starpu_worker_get_perf_archtype(this_worker, STARPU_NMAX_SCHED_CTXS);
+
+	struct starpu_task *task = starpu_task_get_current();
+	unsigned impl = starpu_task_get_implementation(task);
+
+	double length = starpu_task_expected_length(task, perf_arch, impl);
+
+	STARPU_ASSERT_MSG(!_STARPU_IS_ZERO(length) && !isnan(length),
+			"Codelet %s does not have a perfmodel, or is not calibrated enough, please re-run in non-simgrid mode until it is calibrated",
+		starpu_task_get_name(task));
+
+	starpu_sleep(length / 1000000);
 }
 
 /* [CODELET] Initialization of an unique codelet for all the tasks*/
@@ -441,7 +454,7 @@ int submit_tasks(void)
 
 			if (ret_val != 0)
 			{
-				printf("\nWhile submitting task %ld (%s): return %d\n",
+				fprintf(stderr, "\nWhile submitting task %ld (%s): return %d\n",
 						currentTask->submit_order,
 						currentTask->task.name? currentTask->task.name : "unknown",
 						ret_val);
@@ -449,10 +462,10 @@ int submit_tasks(void)
 			}
 
 
-			//printf("submitting task %s (%lu, %llu)\n", currentTask->task.name?currentTask->task.name:"anonymous", currentTask->jobid, (unsigned long long) currentTask->task.tag_id);
+			//fprintf(stderr, "submitting task %s (%lu, %llu)\n", currentTask->task.name?currentTask->task.name:"anonymous", currentTask->jobid, (unsigned long long) currentTask->task.tag_id);
 			if (!(currentTask->submit_order % 1000))
 			{
-				printf("\rSubmitted task order %ld...", currentTask->submit_order);
+				fprintf(stderr, "\rSubmitted task order %ld...", currentTask->submit_order);
 				fflush(stdout);
 			}
 			if (currentTask->submit_order != -1)
@@ -473,7 +486,7 @@ int submit_tasks(void)
 		currentNode = starpu_rbtree_next(currentNode);
 
 	}
-	printf(" done.\n");
+	fprintf(stderr, " done.\n");
 
 	return 1;
 }
@@ -556,7 +569,7 @@ int main(int argc, char **argv)
 
 		if (!fgets(s, s_allocated, rec))
 		{
-			printf(" done.\n");
+			fprintf(stderr, " done.\n");
 			int submitted = submit_tasks();
 
 			if (submitted == -1)
@@ -574,7 +587,7 @@ int main(int argc, char **argv)
 
 			if (!fgets(s + s_allocated-1, s_allocated+1, rec))
 			{
-				printf("\n");
+				fprintf(stderr, "\n");
 				int submitted = submit_tasks();
 
 				if (submitted == -1)
@@ -722,6 +735,7 @@ int main(int argc, char **argv)
 
 					task->task.cl_arg = arg;
 					task->task.flops = flops;
+					total_flops += flops;
 				}
 
 				task->task.cl_arg_size = 0;
@@ -749,7 +763,7 @@ int main(int argc, char **argv)
 			nread_tasks++;
 			if (!(nread_tasks % 1000))
 			{
-				printf("\rRead task %lu...", nread_tasks);
+				fprintf(stderr, "\rRead task %lu...", nread_tasks);
 				fflush(stdout);
 			}
 
@@ -939,9 +953,12 @@ int main(int argc, char **argv)
 eof:
 
 	starpu_task_wait_for_all();
-	printf(" done.\n");
+	fprintf(stderr, " done.\n");
 
-	printf("Simulation ended. Elapsed simulated time: %g ms\n", (starpu_timing_now() - start) / 1000.);
+	printf("%g ms", (starpu_timing_now() - start) / 1000.);
+	if (total_flops != 0.)
+		printf("\t%g GF/s", (total_flops / (starpu_timing_now() - start)) / 1000.);
+	printf("\n");
 
 	/* FREE allocated memory */
 
